`include "cypress.v"

module Pattern(
	//Output Port
	clock,
	en,
	start,
	//Input Port
	interrupt,
	dma_dif,
        dma_vol,
        dma_zcr
);

input 	interrupt;
input   dma_dif;
input   dma_vol;
input   dma_zcr;
output 	clock;
output  en;
output  start;

// Internal Signal Declarations
reg	clock;
reg     en;
reg     start;

reg	CPUClock = 0;
reg [31:0] data_bits;
reg [31:0] data_out;
reg [31:0] data_threshold;
reg [31:0] data_vol;
reg [31:0] data_counter;
reg [7:0]  data_zcr;

localparam cycle = 10;
localparam dma_delay = 200;

initial
begin
	clock = 0;
	en = 0;
        data_counter = 0;
        start = 0;

	$dumpfile("results.vcd");
	$dumpvars;

	#10;
	en = 1; /* Enable block */
	data_out = 0;

	#cycle; 
	start = 1;
	#cycle;
	start = 0;
	
    $display("New Data");
	data_threshold = 32'd31;
	BC_Design.dp_dif.U3.d1_write(data_threshold[31:24]);
	BC_Design.dp_dif.U2.d1_write(data_threshold[23:16]);
	BC_Design.dp_dif.U1.d1_write(data_threshold[15:8]);
	BC_Design.dp_dif.U0.d1_write(data_threshold[7:0]);

        #cycle; 
        data_threshold = 32'd1;
        BC_Design.dp_zcr.U0.d0_write(data_threshold[7:0]);

        #cycle;
        data_threshold = 32'd400;
	BC_Design.dp_vol.U3.d1_write(data_threshold[31:24]);
	BC_Design.dp_vol.U2.d1_write(data_threshold[23:16]);
	BC_Design.dp_vol.U1.d1_write(data_threshold[15:8]);
	BC_Design.dp_vol.U0.d1_write(data_threshold[7:0]);
end

always
begin
    #cycle;
    if (dma_dif == 1)
    begin
	data_out = 0;

	BC_Design.dp_dif.U3.fifo1_read(data_out[31:24]);
	BC_Design.dp_dif.U2.fifo1_read(data_out[23:16]);
	BC_Design.dp_dif.U1.fifo1_read(data_out[15:8]);
	BC_Design.dp_dif.U0.fifo1_read(data_out[7:0]);
        $display("Diff: %d", data_out);

        #cycle
	BC_Design.dp_vol.U3.fifo0_write(data_out[31:24]);
	BC_Design.dp_vol.U2.fifo0_write(data_out[23:16]);	
	BC_Design.dp_vol.U1.fifo0_write(data_out[15:8]);
	BC_Design.dp_vol.U0.fifo0_write(data_out[7:0]);
    end
end

always
begin
    #cycle;
    if (dma_vol == 1)
    begin
	data_vol = 0;

	BC_Design.dp_vol.U3.fifo1_read(data_vol[31:24]);
	BC_Design.dp_vol.U2.fifo1_read(data_vol[23:16]);
	BC_Design.dp_vol.U1.fifo1_read(data_vol[15:8]);
	BC_Design.dp_vol.U0.fifo1_read(data_vol[7:0]);
        $display("Volume: %d", data_vol);
    end
end

always
begin
    #cycle;
    if (dma_zcr == 1)
    begin
	data_zcr = 0;

	BC_Design.dp_zcr.U0.fifo0_read(data_zcr[7:0]);
        $display("ZCR: %d", data_zcr);
    end
end

always
begin
	#(cycle/2) CPUClock = ~CPUClock;
	BC_Design.dp_dif.U0.cpu_clock = CPUClock;
	BC_Design.dp_dif.U1.cpu_clock = CPUClock;
	BC_Design.dp_dif.U2.cpu_clock = CPUClock;
	BC_Design.dp_dif.U3.cpu_clock = CPUClock;

	BC_Design.dp_vol.U0.cpu_clock = CPUClock;
	BC_Design.dp_vol.U1.cpu_clock = CPUClock;
	BC_Design.dp_vol.U2.cpu_clock = CPUClock;
	BC_Design.dp_vol.U3.cpu_clock = CPUClock;

	BC_Design.dp_zcr.U0.cpu_clock = CPUClock;

	clock = CPUClock;
end

always
begin
    	#dma_delay;
	data_bits = 32'd35 + data_counter; //-32'd8202;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = -32'd25;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = 32'd35;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = -32'd35;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = 32'd35; //-32'd8202;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = -32'd35;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = -32'd35;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);
	#dma_delay;
	data_bits = 32'd35;
	BC_Design.dp_dif.U3.fifo0_write(data_bits[31:24]);
	BC_Design.dp_dif.U2.fifo0_write(data_bits[23:16]);	
	BC_Design.dp_dif.U1.fifo0_write(data_bits[15:8]);
	BC_Design.dp_dif.U0.fifo0_write(data_bits[7:0]);

        data_counter = data_counter + 1;
end

endmodule
